# VIRTUE

Virtue supports [Cadence Virtuoso](https://www.cadence.com/) in the
[Viper](http://www.cascode-labs.org/viper/) open circuit design environment
and Viper packages in the Virtuoso commercial circuit design environment.

See the API documentation for more information.

## SKILL in VIPER packages

Virtue allows Viper packages to include
[SKILL](https://www.cadence.com/en_US/home/training/all-courses/83018.html)
code to customize Virtuoso.  If the package recipe follows the instructions,
Virtue will handle the initialization of the package's SKILL code.  Virtue
also includes a standard library of Cadence functions that can be used by
Viper packages.
